<?php

namespace Bydedi\Template;

use Bydedi\Container\ServiceProvider;
use Symfony\Component\DependencyInjection\Reference;

class TemplateServiceProvider extends ServiceProvider
{

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {

        $this->serviceContainer->register('template.name_parser', 'Symfony\Component\Templating\TemplateNameParser');

        $paths = $this->serviceContainer->getParameter('app.paths');
        $theme = $this->serviceContainer->getParameter('app.theme');

        $config = array(
            'template_dir' => $paths['themes'] . '/' . $theme['dir'] . '/templates',
            'compile_dir' => $paths['storage'] . '/template/' . $theme['dir'] . '/compiled',
            'cache_dir' => $paths['storage'] . '/template/' . $theme['dir'] . '/cache',
        );

        // plugins as a service
        $this->serviceContainer->register('template.plugins.url', 'Bydedi\Template\Plugins\UrlPlugin')
            ->addArgument(new Reference('router'));

        $this->serviceContainer->register('template.plugins.render', 'Bydedi\Template\Plugins\RenderPlugin')
            ->addArgument(new Reference('service_container'));

        $this->serviceContainer->register('template.plugins.txt', 'Bydedi\Template\Plugins\TxtPlugin')
            ->addArgument(new Reference('utils.text'));

        $this->serviceContainer->register('template.plugins.image', 'Bydedi\Template\Plugins\ImagePlugin')
            ->addArgument(new Reference('utils.image'));

        $this->serviceContainer->register('template', 'Bydedi\Template\Smarty\SmartyEngine')
            ->setArguments(array(new Reference('template.name_parser'), $config))
            ->addMethodCall('registerPlugins', [[
                    new Reference('template.plugins.url'),
                    new Reference('template.plugins.render'),
                    new Reference('template.plugins.txt'),
                    new Reference('template.plugins.image'),
                ]
            ]);

    }
}
